@@ -105,15 +105,32 @@ void MainWindow::rom_exec(){
             }
         }
 
+        ui->pushButton->setEnabled(false);
+        ui->pushButton_2->setEnabled(false);
         QProcess *myProcess = new QProcess();
+        myProcess->setWorkingDirectory("/home/user/");
+        connect(myProcess, SIGNAL(finished(int)), this, SLOT(process_finished(int)));
+
         QStringList args=current_config;
         //args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
         args<<roms.value(ui->listWidget->currentRow());
         qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core).arg(args.join(" ")).toAscii());
-        myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/");
+        /*if (!myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/"))
+            process_finished(-1);*/
+        myProcess->start("/opt/maemo/usr/games/"+current_core, args);
+        if (!myProcess->waitForStarted(10000)){
+            qDebug() << "Failed to start process.";
+            process_finished(-1);
+        }
     }
 }
 
+void MainWindow::process_finished(int)
+{
+    ui->pushButton->setEnabled(true);
+    ui->pushButton_2->setEnabled(true);
+}
+
 void MainWindow::currentRowChanged ( int  ){
     if (ui->listWidget->currentRow()!=-1){
         game="";
@@ -168,14 +185,14 @@ void MainWindow::set_keys(){
     keyopt = NULL;
 }
 
-void MainWindow::def_cfg() // Настройки которые будут применятся к играм по умолчанию настраиваются этим
+void MainWindow::def_cfg()
 {
     game="";
     cfg->setWindowTitle("Config: default");
     cfg->show();
 }
 
-void MainWindow::gui_cfg() // Настройки поведения GUI - rom dir,bios dir,exit after start
+void MainWindow::gui_cfg()
 {
     QDialog *dlg=new QDialog(this);
     dlg->setMinimumWidth(200);
@@ -199,21 +216,30 @@ void MainWindow::gui_cfg() // Настройки поведения GUI - rom di
     delete dlg;
 }
 
-void MainWindow::set_rom_dir(){
+void MainWindow::set_rom_dir()
+{
     QString dir=QFileDialog::getExistingDirectory(this,tr("ROM Directory"),"/home/user/MyDocs/");
     if (!dir.isEmpty()){
         rom_path=dir;
         settings->setValue("rom_path",rom_path);
+        settings->sync();
+        if (settings->status() != QSettings::NoError)
+            qDebug("Can't save gui config, permission error?");
         lbl1->setText(rom_path);
         get_roms();
     }
 }
-void MainWindow::set_bios_dir(){
+
+void MainWindow::set_bios_dir()
+{
     QString dir=QFileDialog::getExistingDirectory(this,tr("BIOS Directory"),"/home/user/MyDocs/");
     if (!dir.isEmpty()){
         bios_path=dir;
         if (bios_path.right(1)!="/")bios_path+="/";
         settings->setValue("bios_path",bios_path);
+        settings->sync();
+        if (settings->status() != QSettings::NoError)
+            qDebug("Can't save gui config, permission error?");
         lbl2->setText(bios_path);
     }
 }
